# Django Gentemplates

Generate basic set of templates for a model.

### Usage

`$ django-gentemplates <appname> <modelname>`

Will create the following files, with basic rendering:

- modelname_confirm_delete.html
- modelname_create_form.html
- modelname_detail.html
- modelname_form.html
- modelname_list.html
